@@ -13,15 +13,16 @@
 """Here is defined the Index class."""
 
 from __future__ import print_function
-import sys
-from bisect import bisect_left, bisect_right
-from time import time, clock
+import math
+import operator
 import os
 import os.path
+import sys
 import tempfile
-import math
 import warnings
 
+from time import time, clock
+
 import numpy
 
 from tables.idxutils import (calc_chunksize, calcoptlevels,
@@ -38,6 +39,9 @@ from tables.group import Group
 from tables.path import join_path
 from tables.exceptions import PerformanceWarning
 from tables.utils import is_idx, idx2long, lazyattr
+from tables.utilsextension import (nan_aware_gt, nan_aware_ge,
+                                   nan_aware_lt, nan_aware_le,
+                                   bisect_left, bisect_right)
 from tables.lrucacheextension import ObjectCache
 
 from tables._past import previous_api, previous_api_property
@@ -59,8 +63,9 @@ if profile:
 
 
 # The default method for sorting
-defsort = "quicksort"
-# defsort = "mergesort"
+# defsort = "quicksort"
+# Changing to mergesort to fix #441
+defsort = "mergesort"
 
 # Default policy for automatically updating indexes after a table
 # append operation, or automatically reindexing after an
@@ -156,7 +161,6 @@ class Index(NotLoggedMixin, indexesextension.Index, Group):
 
     _c_classId = previous_api_property('_c_classid')
 
-    # <properties>
     kind = property(
         lambda self: {1: 'ultralight', 2: 'light',
                       4: 'medium', 8: 'full'}[self.indsize],
@@ -328,7 +332,6 @@ class Index(NotLoggedMixin, indexesextension.Index, Group):
             pass
         return lbucket
 
-    # </properties>
     def __init__(self, parentnode, name,
                  atom=None, title="",
                  kind=None,
@@ -1501,7 +1504,7 @@ class Index(NotLoggedMixin, indexesextension.Index, Group):
 
         # This method will only works under the assumtion that item
         # *is to be found* in the nslice.
-        assert limits[0] < item <= limits[1]
+        assert nan_aware_lt(limits[0], item) and nan_aware_le(item, limits[1])
         cs = self.chunksize
         ss = self.slicesize
         nelementsLR = self.nelementsILR
@@ -1786,6 +1789,8 @@ class Index(NotLoggedMixin, indexesextension.Index, Group):
         """
 
         if is_idx(key):
+            key = operator.index(key)
+
             if key < 0:
                 # To support negative values
                 key += self.nelements
@@ -1954,8 +1959,8 @@ class Index(NotLoggedMixin, indexesextension.Index, Group):
 
         nchunk = -1
         # Lookup for item1
-        if item1 > b0:
-            if item1 <= b1:
+        if nan_aware_gt(item1, b0):
+            if nan_aware_le(item1, b1):
                 # Search the appropriate chunk in bounds cache
                 nchunk = bisect_left(bounds, item1)
                 # Lookup for this chunk in cache
@@ -1981,8 +1986,8 @@ class Index(NotLoggedMixin, indexesextension.Index, Group):
         else:
             start = 0
         # Lookup for item2
-        if item2 >= b0:
-            if item2 < b1:
+        if nan_aware_ge(item2, b0):
+            if nan_aware_lt(item2, b1):
                 # Search the appropriate chunk in bounds cache
                 nchunk2 = bisect_right(bounds, item2)
                 if nchunk2 != nchunk:
@@ -2157,7 +2162,6 @@ class Index(NotLoggedMixin, indexesextension.Index, Group):
   slicesize := %s
   blocksize := %s
   superblocksize := %s
-  filters := %s
   dirty := %s
   byteorder := %r""" % (self._v_pathname, cpathname,
                         self.optlevel, self.kind,
@@ -2165,8 +2169,7 @@ class Index(NotLoggedMixin, indexesextension.Index, Group):
                         self.nelements,
                         self.chunksize, self.slicesize,
                         self.blocksize, self.superblocksize,
-                        self.filters, self.dirty,
-                        self.byteorder)
+                        self.dirty, self.byteorder)
         retstr += "\n  sorted := %s" % self.sorted
         retstr += "\n  indices := %s" % self.indices
         retstr += "\n  ranges := %s" % self.ranges
